@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -16,12 +16,13 @@ import sys
 from cement.core.controller import expose
 
 from ebcli.objects.platform import PlatformVersion
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text
-from ..core import io, fileoperations
-from ..operations import configops, saved_configs, solution_stack_ops
-from ..objects.exceptions import InvalidSyntaxError, NotFoundError
-from ..lib import utils
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text
+from ebcli.core import io, fileoperations
+from ebcli.operations import configops, saved_configs, solution_stack_ops
+from ebcli.operations.tagops import tagops
+from ebcli.objects.exceptions import InvalidSyntaxError, NotFoundError
+from ebcli.lib import utils
 
 
 class ConfigController(AbstractBaseController):
@@ -36,7 +37,8 @@ class ConfigController(AbstractBaseController):
             (['-nh', '--nohang'], dict(action='store_true',
                                        help=flag_text['config.nohang'])),
             (['--timeout'], dict(type=int, help=flag_text['general.timeout'])),
-            (['--cfg'], dict(help='name of configuration'))
+            (['--cfg'], dict(help='name of configuration')),
+            (['--tags'], dict(help=flag_text['config.tags']))
         ]
         epilog = strings['config.epilog']
 
@@ -47,10 +49,8 @@ class ConfigController(AbstractBaseController):
         nohang = self.app.pargs.nohang
         cfg = self.app.pargs.cfg
 
-        # input_exists = False
         input_exists = not sys.stdin.isatty()
         if not cfg and not input_exists:
-            # No input, run interactive editor
             configops.update_environment_configuration(app_name, env_name,
                                                        nohang,
                                                        timeout=timeout)
@@ -73,11 +73,13 @@ class ConfigController(AbstractBaseController):
         env_name = self.get_env_name(varname='name',
                                      cmd_example='eb config save')
         app_name = self.get_app_name()
+        tags = self.app.pargs.tags
+        tags = tagops.get_and_validate_tags(tags)
 
         if not cfg_name:
             cfg_name = self._choose_cfg_name(app_name, env_name)
 
-        saved_configs.create_config(app_name, env_name, cfg_name)
+        saved_configs.create_config(app_name, env_name, cfg_name, tags)
         if fileoperations.env_yaml_exists():
             io.echo(strings['config.envyamlexists'])
 
