@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -18,21 +18,30 @@ from ebcli.resources.strings import strings
 
 DEFAULT_LIFECYCLE_SERVICE_ROLE = 'aws-elasticbeanstalk-service-role'
 DEFAULT_ARN_STRING = 'REPLACE_WITH_ARN'
-DEFAULT_LIFECYCLE_CONFIG = {u'VersionLifecycleConfig':
-                                        {u'MaxCountRule': {u'DeleteSourceFromS3': False, u'Enabled': False,
-                                                           u'MaxCount': 200},
-                                         u'MaxAgeRule': {u'DeleteSourceFromS3': False, u'Enabled': False,
-                                                         u'MaxAgeInDays': 180}}}
+DEFAULT_LIFECYCLE_CONFIG = {
+    u'VersionLifecycleConfig': {
+        u'MaxCountRule': {
+            u'DeleteSourceFromS3': False,
+            u'Enabled': False,
+            u'MaxCount': 200
+        },
+        u'MaxAgeRule': {
+            u'DeleteSourceFromS3': False,
+            u'Enabled': False,
+            u'MaxAgeInDays': 180
+        }
+    }
+}
+
 
 class LifecycleConfiguration(ConversionConfiguration):
     def collect_changes(self, usr_model):
         """
-            Because we can't remove options from the lifecycle config we can only add to them so we just take the
-                direct user model and apply that.
-            :param usr_model: User model, key-value style
-            :return: api_model
+        Because we can't remove options from the lifecycle config we can only
+        add to them so we just take the direct user model and apply that.
+        :param usr_model: User model, key-value style
+        :return: api_model
         """
-        # Validate the service role they gave us exists
         if 'ServiceRole' in usr_model['Configurations']:
             service_role = usr_model['Configurations']['ServiceRole'].split('/')[-1]
             try:
@@ -43,13 +52,13 @@ class LifecycleConfiguration(ConversionConfiguration):
 
     def convert_api_to_usr_model(self):
         """
-            Convert an api model to a User model as a key-value system and remove unwanted entries, we will place a
-                default Service Role if there is none present to begin with.
-            :return: a user model
+        Convert an api model to a User model as a key-value system and remove
+        unwanted entries, we will place a default Service Role if there is
+        none present to begin with.
+        :return: a user model
         """
 
         usr_model = dict()
-        # Grab only data we care about
         self._copy_api_entry('ApplicationName', usr_model)
         self._copy_api_entry('DateUpdated', usr_model)
         if 'ResourceLifecycleConfig' in self.api_model:
@@ -57,14 +66,12 @@ class LifecycleConfiguration(ConversionConfiguration):
         else:
             usr_model['Configurations'] = DEFAULT_LIFECYCLE_CONFIG
 
-            # If the service role is not in the current user model put the default role in it's place.
         if 'ServiceRole' not in usr_model['Configurations']:
             try:
                 role = get_role(DEFAULT_LIFECYCLE_SERVICE_ROLE)
                 if u'Arn' in role:
                     arn = role[u'Arn']
                 else:
-                    # IAM should always return the arn, just being extra safe
                     arn = DEFAULT_ARN_STRING
             except (NotFoundError, ServiceError):
                 arn = DEFAULT_ARN_STRING
