@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,12 +11,15 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..lib import elasticbeanstalk
-from . import commonops
+from ebcli.lib import elasticbeanstalk
+from ebcli.operations import commonops
 
 
 def cname_swap(source_env, dest_env):
     request_id = elasticbeanstalk.swap_environment_cnames(source_env, dest_env)
 
-    commonops.wait_for_success_events(request_id, timeout_in_minutes=1,
-                            sleep_time=2)
\ No newline at end of file
+    commonops.wait_for_success_events(
+        request_id,
+        timeout_in_minutes=1,
+        sleep_time=2
+    )
